@@ -7,7 +7,7 @@ use warnings;
 use autodie;
 use namespace::autoclean;
 
-our $VERSION = '0.12';
+our $VERSION = '0.13';
 
 use Dist::Zilla;
 
@@ -318,6 +318,12 @@ sub _build_plugins {
         [
             UploadToCPAN => { pause_cfg_file => '.pause-maxmind' },
         ],
+        [
+            SurgicalPodWeaver => {
+                replacer           => 'replace_with_comment',
+                post_code_replacer => 'replace_with_nothing',
+            },
+        ],
 
         # from @Basic
         qw(
@@ -348,7 +354,6 @@ sub _build_plugins {
             MetaJSON
             MinimumPerl
             RewriteVersion
-            SurgicalPodWeaver
             ),
         qw(
             PodSyntaxTests
@@ -444,7 +449,7 @@ Dist::Zilla::PluginBundle::MAXMIND - MaxMind's plugin bundle
 
 =head1 VERSION
 
-version 0.12
+version 0.13
 
 =for Pod::Coverage .*
 
@@ -452,15 +457,25 @@ version 0.12
 
 Dave Rolsky <drolsky@maxmind.com>
 
-=head1 CONTRIBUTOR
+=head1 CONTRIBUTORS
 
-=for stopwords Mateu X Hunter
+=for stopwords Mark Fowler Mateu X Hunter
+
+=over 4
+
+=item *
+
+Mark Fowler <mfowler@maxmind.com>
+
+=item *
 
 Mateu X Hunter <mhunter@maxmind.com>
 
+=back
+
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 - 2015 by MaxMind, Inc..
+This software is copyright (c) 2014 - 2016 by MaxMind, Inc..
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
